Tracker class
Constructors
- Tracker()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentRoute ↔ String
-
getter/setter pair
- debug ↔ bool
-
getter/setter pair
-
logButtonEvent
↔ Future<
void> Function({required String name, Map<String, Object> ? parameters}) -
getter/setter pair
-
logScreenEvent
↔ Future<
void> Function({required String name, Map<String, Object> ? parameters}) -
getter/setter pair
Static Methods
-
configure(
{bool debugMode = false, required Future< void> logScreenEventFunction({required String name, Map<String, Object> ? parameters}), required Future<void> logButtonClickEvent({required String name, Map<String, Object> ? parameters})}) → Future<void> -
logClickEvent(
String key, BuildContext context) → Future< void> -
setCurrentRoute(
String routeName) → void